@@ -1,7 +1,26 @@
+package Crypt::Rijndael;
+
+use strict;
+use warnings;
+
+our $VERSION = '1.14';
+
+use XSLoader;
+
+XSLoader::load('Crypt::Rijndael', $VERSION);
+
+1;
+
+__END__
+
 =head1 NAME
 
 Crypt::Rijndael - Crypt::CBC compliant Rijndael encryption module
 
+=head1 VERSION
+
+Version 1.14
+
 =head1 SYNOPSIS
 
  use Crypt::Rijndael;
@@ -23,22 +42,6 @@ as the Advanced Encryption Standard.
 
 =over 4
 
-=cut
-
-package Crypt::Rijndael;
-use strict;
-use vars qw( $VERSION @ISA );
-
-use warnings;
-no warnings;
-
-require DynaLoader;
-
-$VERSION = '1.06';
-@ISA = qw/DynaLoader/;
-
-bootstrap Crypt::Rijndael $VERSION;
-
 =item keysize
 
 Returns the keysize, which is 32 (bytes). The Rijndael cipher
@@ -61,7 +64,7 @@ codebook mode, the default), C<MODE_CBC> (cipher block chaining, the
 same that C<Crypt::CBC> does), C<MODE_CFB> (128-bit cipher feedback),
 C<MODE_OFB> (128-bit output feedback), or C<MODE_CTR> (counter mode).
 
-ECB mode is very insecure (read a book on cryptography if you dont
+ECB mode is very insecure (read a book on cryptography if you don't
 know why!), so you should probably use CBC mode.
 
 =item $cipher->set_iv($iv)
@@ -111,19 +114,25 @@ Should EXPORT or EXPORT_OK the MODE constants.
 
 =head1 AUTHOR
 
-Currently maintained by brian d foy, C<< <bdfoy@cpan.org> >>.
+Currently maintained by Leon Timmermans C<< leont@cpan.org >>.
+
+Previously maintained by brian d foy, C<< <bdfoy@cpan.org> >>.
 
 Original code by  Rafael R. Sevilla.
 
 The Rijndael Algorithm was developed by Vincent Rijmen and Joan Daemen,
 and has been selected as the US Government's Advanced Encryption Standard.
 
+=head1 SOURCE
+
+This code is in Github:
+
+	git://github.com/leont/crypt-rijndael.git
+	
 =head1 LICENSE
 
-This software is licensed under the GNU Public License. See the included
-COPYING file for details.
+This software is licensed under the Lesser GNU Public License v3 (29
+June 2007). See the included COPYING file for details.
 
 =cut
 
-1;
-
